//$Id: widget-util.h,v 1.2 2001/10/16 16:11:49 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_WIDGET_UTIL_H
#define GUIKACHU_FORM_EDITOR_WIDGET_UTIL_H

#include <string>
#include "widget.h"
#include <glib.h>

namespace Guikachu
{
    namespace Widgets
    {
	const string type_id_from_type       (Type          type)    G_GNUC_CONST;
	Type         type_from_type_id       (const string &type_id);

	const string display_name_from_type  (Type          type)    G_GNUC_CONST;
	const char * const * type_icon       (Type          type)    G_GNUC_CONST;
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_WIDGET_UTIL_H */
